==> scraping-1.2.6-sources.jar: com/tenqube/visual_scraper/crawler/MallCrawler.java <==
package com.tenqube.visual_scraper.crawler;

import android.content.Context;
import android.webkit.WebView;

import com.tenqube.visual_scraper.crawler.model.CrawlerRequestData;
import com.tenqube.visual_scraper.crawler.model.CrawlerUrl;
import com.tenqube.visual_scraper.scrap.mall.Mall;

import static com.tenqube.visual_scraper.crawler.ScrapInterface.SHOW_HTML_JS;

public class MallCrawler extends Crawler {

    private int retryCnt;

    private Mall mall;

    public MallCrawler(Context context,
                       CrawlerRequestData requestData,
                       CrawlerCallback crawlerCallback) {
        super(context, requestData, crawlerCallback);
    }

    public void setMall(Mall mall) {
        this.mall = mall;
    }

    @Override
    public void onTimeOut() {

        // 로그인인 경우
//        if(mUrl.getAction() == Constants.CrawlerAction.LOGIN) {
//
//            loadUrl(CHECK_HTML_JS);
//        } else {
//            crawlerCallback.onFail("time out");
//        }

    }

    @Override
    public void checkHtml(String html) {

//        if (mall.hasError()) {
//            crawlerCallback.onFail("login Error");
//        } else if (mall.hasCapcha()){
//            crawlerCallback.addView(webManager.getWebView(), View.VISIBLE);
//        } else {
//            // 재시도
//            if(mUrl != null && retryCnt < 3) {
//                retryCnt++;
//                loadUrl(mUrl.getUrl());
//            }
//        }
    }

    @Override
    public void onPageFinished(WebView view, String url) {

        CrawlerUrl crawlerUrl = getCrawlerUrl();
        if(crawlerUrl == null) {
            loadUrl(SHOW_HTML_JS);
        } else {
            loadUrl(crawlerUrl.getUrl());
        }
    }
}

==> scraping-1.4.8-sources.jar: com/tenqube/visual_scraper/crawler/MallCrawler.java <==
package com.tenqube.visual_scraper.crawler;

import android.content.Context;
import android.webkit.WebView;

import com.tenqube.visual_scraper.crawler.model.CrawlerRequestData;
import com.tenqube.visual_scraper.crawler.model.CrawlerUrl;
import com.tenqube.visual_scraper.mall.Mall;

import static com.tenqube.visual_scraper.crawler.ScrapInterface.SHOW_HTML_JS;

public class MallCrawler extends Crawler {

    private int retryCnt;

    private Mall mall;

    public MallCrawler(Context context,
                       CrawlerRequestData requestData,
                       CrawlerCallback crawlerCallback) {
        super(context, requestData, crawlerCallback);
    }

    public void setMall(Mall mall) {
        this.mall = mall;
    }

    @Override
    public void onTimeOut() {

        // 로그인인 경우
//        if(mUrl.getAction() == Constants.CrawlerAction.LOGIN) {
//
//            loadUrl(CHECK_HTML_JS);
//        } else {
//            crawlerCallback.onFail("time out");
//        }

    }

    @Override
    public void checkHtml(String html) {

//        if (mall.hasError()) {
//            crawlerCallback.onFail("login Error");
//        } else if (mall.hasCapcha()){
//            crawlerCallback.addView(webManager.getWebView(), View.VISIBLE);
//        } else {
//            // 재시도
//            if(mUrl != null && retryCnt < 3) {
//                retryCnt++;
//                loadUrl(mUrl.getUrl());
//            }
//        }
    }

    @Override
    public void onPageFinished(WebView view, String url) {

        CrawlerUrl crawlerUrl = getCrawlerUrl();
        if(crawlerUrl == null) {
            loadUrl(SHOW_HTML_JS);
        } else {
            loadUrl(crawlerUrl.getUrl());
        }
    }
}
